@@ -3,8 +3,9 @@ use v5.10;
 use Dancer ':syntax';
 use Dancer::Plugin;
 use Scalar::Util 'blessed';
+use Time::HiRes 'time';
 
-our $VERSION = '1.08';
+our $VERSION = '1.09';
 
 no if $] >= 5.018, warnings => 'experimental::smartmatch';
 
@@ -27,14 +28,16 @@ register PLUGIN_NAME ,=> sub {
     my ($self, $endpoint, $arguments) = plugin_args(@_);
 
     my $publisher;
-    given ($arguments->{publish} // 'config') {
-        when (exists $dispatch_builder_map{$_}) {
+    GIVEN: {
+        local $_ = $arguments->{publish} // 'config';
+        exists($dispatch_builder_map{$_}) && do {
             $publisher = $dispatch_builder_map{$_};
             $arguments->{arguments} = plugin_setting() if $_ eq 'config';
-        }
-        default {
+            last GIVEN;
+        };
+        do {
             $publisher = $_;
-        }
+        };
     }
     my $dispatcher = $publisher->($arguments->{arguments}, $endpoint);
 
@@ -88,6 +91,7 @@ register PLUGIN_NAME ,=> sub {
 
             my $method_args = $request->{params};
 
+            my $start_request = time();
             debug("[handle_jsonrpc_call($method_name)] ", $method_args);
             my Dancer::RPCPlugin::CallbackResult $continue = eval {
                 local $Dancer::RPCPlugin::ROUTE_INFO = {
@@ -146,6 +150,10 @@ register PLUGIN_NAME ,=> sub {
             my $error = $@;
 
             debug("[handled_jsonrpc_request($method_name)] ", flatten_data($result));
+            info( sprintf(
+                "[RPC::JSONRPC] request for %s took %.4fs",
+                $method_name, time() - $start_request
+            ));
             if ($error) {
                 my $error_response = blessed($error) && $error->can('as_jsonrpc_error')
                     ? $error
