@@ -30,12 +30,14 @@ register PLUGIN_NAME ,=> sub {
     my($self, $endpoint, $arguments) = plugin_args(@_);
 
     my $publisher;
-    given ($arguments->{publish} // 'config') {
-        when (exists $dispatch_builder_map{$_}) {
+    GIVEN: {
+        local $_ = $arguments->{publish} // 'config';
+        exists($dispatch_builder_map{$_}) && do {
             $publisher = $dispatch_builder_map{$_};
             $arguments->{arguments} = plugin_setting() if $_ eq 'config';
-        }
-        default {
+            last GIVEN;
+        };
+        do {
             $publisher = $_;
         }
     }
